summaryrefslogtreecommitdiffstats
path: root/src/H5HL.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
commit31431be37492b0446c048401bcb9512ae23ef8f4 (patch)
tree9928afd828704483be974f8e2cd8238bbc576869 /src/H5HL.c
parent1b1e1ebbbd5b4d18c5f413e79b58f7f7e782519f (diff)
downloadhdf5-31431be37492b0446c048401bcb9512ae23ef8f4.zip
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.gz
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.bz2
[svn-r7917] Purpose:
Code cleanup Description: Clean up compiler warnings, especially the 'FUNC' variable not used which comes out in production mode. Solution: Had to add a new FUNC_ENTER_NOAPI_NOINIT_NOFUNC macro for those non-API functions which don't need the 'FUNC' variable defined. (This will be _so_ much easier when C99 is standard on all our supposed platforms, since it has a __FUNC__ macro... ) Platforms tested: FreeBSD 4.9 (sleipnir) too minor for h5committest (although there were lots of files changed, the change was minor in each one)
Diffstat (limited to 'src/H5HL.c')
-rw-r--r--src/H5HL.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5HL.c b/src/H5HL.c
index b33b75f..67165d9 100644
--- a/src/H5HL.c
+++ b/src/H5HL.c
@@ -475,7 +475,7 @@ H5HL_serialize(H5F_t *f, H5HL_t *heap, uint8_t *buf)
uint8_t *p;
herr_t ret_value = SUCCEED;
- FUNC_ENTER_NOINIT(H5HL_serialize)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_serialize)
/* check args */
assert(buf);
@@ -614,7 +614,7 @@ H5HL_dest(H5F_t UNUSED *f, H5HL_t *heap)
{
H5HL_free_t *fl;
- FUNC_ENTER_NOINIT(H5HL_dest);
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_dest);
/* check arguments */
assert(heap);
@@ -655,7 +655,7 @@ H5HL_clear(H5F_t *f, H5HL_t *heap, hbool_t destroy)
{
herr_t ret_value = SUCCEED;
- FUNC_ENTER_NOINIT(H5HL_clear);
+ FUNC_ENTER_NOAPI_NOINIT(H5HL_clear);
/* check arguments */
assert(heap);
@@ -808,9 +808,9 @@ H5HL_offset_into(H5F_t *f, const H5HL_t *heap, size_t offset)
{
/*
* We need to have called some other function before this to get a
* valid heap pointer. So, this can remain "FUNC_ENTER_NOINIT"
*/
- FUNC_ENTER_NOINIT(H5HL_offset_into)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_offset_into)
assert(f);
assert(heap);
assert(offset < heap->mem_alloc);
@@ -873,7 +873,7 @@ done:
static H5HL_free_t *
H5HL_remove_free(H5HL_t *heap, H5HL_free_t *fl)
{
- FUNC_ENTER_NOINIT(H5HL_remove_free);
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5HL_remove_free);
if (fl->prev) fl->prev->next = fl->next;
if (fl->next) fl->next->prev = fl->prev;
@@ -808,9 +808,9 @@ H5HL_offset_into(H5F_t *f, const H5HL_t *heap, size_t offset)
/*
* We need to have called some other function before this to get a
- * valid heap pointer. So, this can remain "FUNC_ENTER_NOINIT"
+ * valid heap pointer. So, this can remain "FUNC_ENTER_NOAPI_NOINIT"
*/